Data documentation compiled by Great Expectations

### Expectation Suite Overview

#### Info

Full Data Asset Identifier | my_datasource/my_generator/titanic_data
Data Asset Type | Dataset
Expectation Suite Name | default
Great Expectations Version | 0.7.0-beta

#### Notes

This Expectation suite currently contains 43 total Expectations across 7 columns.

### Age

- value types must belong to this set: DOUBLE_PRECISION DoubleType FLOAT FloatType NUMERIC float.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- minimum value may have any numerical value.
- maximum value may have any numerical value.
- mean may have any numerical value.
- median may have any numerical value.
- expect_column_quantile_values_to_be_between(**OrderedDict([('column', 'Age'), ('quantile_ranges', OrderedDict([('quantiles', [0.05, 0.25, 0.5, 0.75, 0.95]), ('value_ranges', [[None, None], [None, None], [None, None], [None, None], [None, None]])]))]))
- Kullback-Leibler (KL) divergence with respect to a given distribution must be lower than a provided threshold but no distribution was specified.

### Name

- value types must belong to this set: CHAR StringType TEXT VARCHAR str string.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.

### PClass

- value types must belong to this set: CHAR StringType TEXT VARCHAR str string.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must not match this regular expression: ^\s+|\s+$.
- distinct values must belong to a set, but that set is not specified.

### Sex

- value types must belong to this set: CHAR StringType TEXT VARCHAR str string.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must not match this regular expression: ^\s+|\s+$.
- distinct values must belong to a set, but that set is not specified.

### SexCode

- value types must belong to this set: BIGINT INTEGER IntegerType LongType SMALLINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- distinct values must belong to a set, but that set is not specified.

### Survived

- value types must belong to this set: BIGINT INTEGER IntegerType LongType SMALLINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- distinct values must belong to a set, but that set is not specified.

### Unnamed: 0

- value types must belong to this set: BIGINT INTEGER IntegerType LongType SMALLINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must not be null, at least 50.0 % of the time.
- values must be unique.

### None

- Must have more than 0 rows.
- This table should have a list of columns in a specific order, but that order is not specified.

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.